# Possible Documentation Topics

* Getting Started as code intro, not installation instructions
* Constraining
* Interactive Queries (Chat)
* Queries that call functions
* Playground Manual
* Decoding Graphs
* More Discussion of Individual Website Examples
